@@ -17,10 +17,7 @@ def detect(get_page):
 
     for vector in WAF_ATTACK_VECTORS:
         page, headers, code = get_page(get=vector)
-        retval = headers.get("X-Varnish") is not None
-        retval |= re.search(r"varnish\Z", headers.get(HTTP_HEADER.VIA, ""), re.I) is not None
-        retval |= re.search(r"varnish", headers.get(HTTP_HEADER.SERVER, ""), re.I) is not None
-        retval |= code == 404 and re.search(r"\bXID: \d+", page or "") is not None
+        retval = code == 404 and re.search(r"\bXID: \d+", page or "") is not None
         retval |= code >= 400 and "Request rejected by xVarnish-WAF" in (page or "")
         if retval:
             break
